package com.zhyc.module.app.service;

import java.util.List;
import com.zhyc.module.app.domain.AppVersion;

/**
 * 应用版本信息Service接口
 * 
 * @author ruoyi
 * @date 2025-12-09
 */
public interface IAppVersionService 
{
    /**
     * 查询应用版本信息
     * 
     * @param id 应用版本信息主键
     * @return 应用版本信息
     */
    public AppVersion selectAppVersionById(Long id);

    /**
     * 查询应用版本信息列表
     * 
     * @param appVersion 应用版本信息
     * @return 应用版本信息集合
     */
    public List<AppVersion> selectAppVersionList(AppVersion appVersion);

    /**
     * 新增应用版本信息
     * 
     * @param appVersion 应用版本信息
     * @return 结果
     */
    public int insertAppVersion(AppVersion appVersion);

    /**
     * 修改应用版本信息
     * 
     * @param appVersion 应用版本信息
     * @return 结果
     */
    public int updateAppVersion(AppVersion appVersion);

    /**
     * 批量删除应用版本信息
     * 
     * @param ids 需要删除的应用版本信息主键集合
     * @return 结果
     */
    public int deleteAppVersionByIds(Long[] ids);

    /**
     * 删除应用版本信息信息
     * 
     * @param id 应用版本信息主键
     * @return 结果
     */
    public int deleteAppVersionById(Long id);
}
